@@ -27,40 +27,40 @@
 
 """
 PCHJLIB😺
-===============================================================================
--------------------------------------------------------------------------------
+================================================================================================
+------------------------------------------------------------------------------------------------
 Author
--------------------------------------------------------------------------------
+------------------------------------------------------------------------------------------------
 - Joesifer.
 
 Version
--------------------------------------------------------------------------------
-- 1.1.2.
+------------------------------------------------------------------------------------------------
+- 1.1.8.
 
 Release Date
--------------------------------------------------------------------------------
+------------------------------------------------------------------------------------------------
 - February 14, 2024.
 
 License
--------------------------------------------------------------------------------
+------------------------------------------------------------------------------------------------
 - Copyright © 2024 Joesifer
 
 Supported Python Version
--------------------------------------------------------------------------------
+------------------------------------------------------------------------------------------------
 - Python 3.7 or higher.
 
 Dependencies
--------------------------------------------------------------------------------
+------------------------------------------------------------------------------------------------
 - Built-in: `math`, `re`, `random`, `functools`, `argparse`.
 - External: `numpy` (optional for `solve_equation` and `generate_prime_list`).
 - External (plan): `gmpy2` (optional for big integer support).
 
 License Type
--------------------------------------------------------------------------------
+------------------------------------------------------------------------------------------------
 - MIT License.
 
 Additional Information
--------------------------------------------------------------------------------
+------------------------------------------------------------------------------------------------
 
 For usage instructions, please refer to:
   >>> Link: https://github.com/Joesifer/pchjlib/blob/main/README.md
@@ -69,15 +69,12 @@ Feedback and support are welcome via:
   >>> Email: `phanchanhung12055@gmail.com`
 
 THANK YOU!!!
-===============================================================================
+================================================================================================
 """
 
 import math, random, re, argparse
 from functools import lru_cache
 
-__author__ = "Joesifer (phanchanhung12055@gmail.com)"
-__copyright__ = "Copyright (c) 2024 Joesifer"
-
 
 # Custom exception classes
 class MathError(Exception):
@@ -1261,7 +1258,7 @@ def generate_sequence_rule_1(number):
         - 1 number is divisible by 1,
         - 2 numbers are divisible by 2,
         - 3 numbers are divisible by 3,
-        - and so on, with increasing numbers and no duplicates.
+        - and so on, the numbers increase until the number of numbers is `number`
 
     Parameters:
         - number (int): The number of elements to generate.
@@ -1390,7 +1387,7 @@ For more options, use -h or --help with each category.
         "-v",
         "--version",
         action="version",
-        version="%(prog)s 1.1.2",
+        version="%(prog)s 1.1.8",
         help="Display the library version",
     )
 
@@ -2032,7 +2029,7 @@ For more options, use -h or --help with each category.
                 print(f"Error: {e}")
 
     else:
-        print("Welcome to pchjlib version 1.1.2!")
+        print("Welcome to pchjlib version 1.1.8!")
         print("Use -h or --help for more information.")
 
 
